@@ -24,10 +24,10 @@
 
 #include <QtCore/QAbstractTableModel>
 
-#include <KDE/KTextEditor/MarkInterface>
+#include <KTextEditor/MarkInterface>
 #include "breakpoint.h"
 
-class KUrl;
+class QUrl;
 
 namespace KParts { class Part; }
 namespace KTextEditor {
@@ -44,25 +44,81 @@ class KDEVPLATFORMDEBUGGER_EXPORT BreakpointModel : public QAbstractTableModel
     Q_OBJECT
 
 public:
-    BreakpointModel(QObject* parent);
+    enum Column {
+        /**
+         * Whether the breakpoint is active or not (settable by user): value is Qt::Checked
+         * or Qt::Unchecked.
+         */
+        EnableColumn,
+
+        /**
+         * Synchronization state of the breakpoint (not settable by user): value is one of the
+         * BreakpointState enum values.
+         */
+        StateColumn,
+
+        /**
+         * Kind/type of breakpoint (never changes): value is one of the BreakpointKind
+         * enum values.
+         */
+        KindColumn,
+
+        /**
+         * Location of the breakpoint (modifiable by user); value is a string describing the
+         * location; note that the formatting of retrieved data can be affected by a custom
+         * BreakpointRole.
+         */
+        LocationColumn,
+
+        /**
+         * Condition for conditional breakpoints (modifiable by user).
+         */
+        ConditionColumn,
+
+        /**
+         * The number of times this breakpoint has been hit (cannot be modified by the user).
+         */
+        HitCountColumn,
+
+        /**
+         * How many hits of the breakpoint will be ignored before the breakpoint actually stops
+         * the program (can be modified by the user and is updated by the debugger backend).
+         */
+        IgnoreHitsColumn,
+
+        NumColumns
+    };
+
+    enum ColumnFlag {
+        EnableColumnFlag = 1 << EnableColumn,
+        StateColumnFlag = 1 << StateColumn,
+        KindColumnFlag = 1 << KindColumn,
+        LocationColumnFlag = 1 << LocationColumn,
+        ConditionColumnFlag = 1 << ConditionColumn,
+        HitCountColumnFlag = 1 << HitCountColumn,
+        IgnoreHitsColumnFlag = 1 << IgnoreHitsColumn
+    };
+    Q_DECLARE_FLAGS(ColumnFlags, ColumnFlag)
+
+    explicit BreakpointModel(QObject* parent);
     virtual ~BreakpointModel();
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const;
-    Qt::ItemFlags flags(const QModelIndex &index) const;
+    QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
     QModelIndex breakpointIndex(Breakpoint *b, int column);
-    virtual bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex());
-    virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
-    virtual int columnCount(const QModelIndex& parent = QModelIndex()) const;
+    bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex()) override;
+    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
      ///Note: to retrieve the full path use Breakpoint::LocationRole, Qt::DisplayRole returns only a file's name
-    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
-    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
+    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
+    bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override;
  
-    void toggleBreakpoint(const KUrl &url, const KTextEditor::Cursor& cursor);
+    void toggleBreakpoint(const QUrl &url, const KTextEditor::Cursor& cursor);
 
 
     KDevelop::Breakpoint* addCodeBreakpoint();
-    KDevelop::Breakpoint* addCodeBreakpoint(const KUrl& location, int line);
+    KDevelop::Breakpoint* addCodeBreakpoint(const QUrl& location, int line);
     KDevelop::Breakpoint* addCodeBreakpoint(const QString& expression);
     KDevelop::Breakpoint* addWatchpoint();
     KDevelop::Breakpoint* addWatchpoint(const QString& expression);
@@ -74,12 +130,9 @@ public:
     Breakpoint *breakpoint(int row);
     QList<Breakpoint*> breakpoints() const;
 
-    void errorEmit(Breakpoint *b, const QString& message, int column) { emit error(b, message, column); }
-    void hitEmit(Breakpoint *b) { emit hit(b); }
-
 Q_SIGNALS:
-    void error(KDevelop::Breakpoint *b, const QString& message, int column);
-    void hit(KDevelop::Breakpoint *b);
+    void error(int row, const QString& errorText);
+    void hit(int row);
 
 public Q_SLOTS:
     void save();
@@ -95,14 +148,6 @@ private:
         AllBreakpointMarks = BreakpointMark | ReachedBreakpointMark | DisabledBreakpointMark | PendingBreakpointMark
     };
 
-Q_SIGNALS:
-    /**
-     * A breakpoint has been deleted by the user. The breakpoint object
-     * still exists as is has eventualle be deleted from the debugger engine.
-     */
-    void breakpointDeleted(KDevelop::Breakpoint *breakpoint);
-    void breakpointChanged(KDevelop::Breakpoint *breakpoint, KDevelop::Breakpoint::Column column);
-
 private Q_SLOTS:
 
     void updateMarks();
@@ -131,18 +176,27 @@ private:
 
 private:
     friend class Breakpoint;
+    friend class IBreakpointController;
+
+    void updateState(int row, Breakpoint::BreakpointState state);
+    void updateHitCount(int row, int hitCount);
+    void updateErrorText(int row, const QString& errorText);
+    void notifyHit(int row);
 
     void registerBreakpoint(Breakpoint* breakpoint);
+    void scheduleSave();
 
     void reportChange(Breakpoint *breakpoint, Breakpoint::Column column);
     uint breakpointType(Breakpoint *breakpoint);
-    Breakpoint *breakpoint(const KUrl& url, int line);
+    Breakpoint *breakpoint(const QUrl& url, int line);
 
+    bool m_dirty = false;
     bool m_dontUpdateMarks;
     QList<Breakpoint*> m_breakpoints;
 };
 
-
 }
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(KDevelop::BreakpointModel::ColumnFlags)
+
 #endif
