@@ -125,7 +125,7 @@ void DocumentationView::initialize()
 
 void DocumentationView::browseBack()
 {
-    mCurrent--;
+    --mCurrent;
     mBack->setEnabled(mCurrent != mHistory.begin());
     mForward->setEnabled(true);
 
@@ -134,7 +134,7 @@ void DocumentationView::browseBack()
 
 void DocumentationView::browseForward()
 {
-    mCurrent++;
+    ++mCurrent;
     mForward->setEnabled(mCurrent+1 != mHistory.end());
     mBack->setEnabled(true);
 
