@@ -58,7 +58,8 @@ public:
         DefaultMode = 0,            /**Activate document and create a view if no other flags passed.*/
         DoNotActivate = 1,          /**Don't activate the Document.*/
         DoNotCreateView = 2,        /**Don't create and show the view for the Document.*/
-        DoNotFocus = 4              /**Don't change the keyboard focus.*/
+        DoNotFocus = 4,             /**Don't change the keyboard focus.*/
+        DoNotAddToRecentOpen = 8,   /**Don't add the document to the File/Open Recent menu.*/
     };
     Q_DECLARE_FLAGS(DocumentActivationParams, DocumentActivation)
 
@@ -107,12 +108,12 @@ public Q_SLOTS:
      * Opens a new or existing document.
      *
      * @param url The full Url of the document to open.
-     * @param range The location information, if applicable.
-     * @param activate Indicates whether to fully activate the document.
+     * @param cursor The location information, if applicable.
+     * @param activationParams Indicates whether to fully activate the document.
      */
     KDevelop::IDocument* openDocument( const QUrl &url,
             const KTextEditor::Cursor& cursor,
-            DocumentActivationParams activationParams = 0,
+            DocumentActivationParams activationParams = nullptr,
             const QString& encoding = {});
 
     /**
@@ -120,7 +121,7 @@ public Q_SLOTS:
      *
      * @param url The full Url of the document to open.
      * @param range The range of text to select, if applicable.
-     * @param activate Indicates whether to fully activate the document
+     * @param activationParams Indicates whether to fully activate the document
      * @param buddy Optional buddy document. If 0, the registered IBuddyDocumentFinder
      *              for the URL's mimetype will be queried to find a fitting buddy.
      *              If a buddy was found (or passed) @p url will be opened next
@@ -130,9 +131,9 @@ public Q_SLOTS:
      */
     virtual KDevelop::IDocument* openDocument( const QUrl &url,
             const KTextEditor::Range& range = KTextEditor::Range::invalid(),
-            DocumentActivationParams activationParams = 0,
+            DocumentActivationParams activationParams = nullptr,
             const QString& encoding = {},
-            IDocument* buddy = 0) = 0;
+            IDocument* buddy = nullptr) = 0;
 
     /**
      * Opens a document from the IDocument instance.
@@ -147,8 +148,8 @@ public Q_SLOTS:
      */
     virtual Q_SCRIPTABLE bool openDocument(IDocument* doc,
             const KTextEditor::Range& range = KTextEditor::Range::invalid(),
-            DocumentActivationParams activationParams = 0,
-            IDocument* buddy = 0) = 0;
+            DocumentActivationParams activationParams = nullptr,
+            IDocument* buddy = nullptr) = 0;
 
     /**
      * Opens a new or existing document.
@@ -156,7 +157,7 @@ public Q_SLOTS:
      * @param url The full Url of the document to open.
      * @param prefName The name of the preferred KPart to open that document
      */
-    virtual KDevelop::IDocument* openDocument( const QUrl &url, const QString& prefname ) = 0;
+    virtual KDevelop::IDocument* openDocument( const QUrl &url, const QString& prefName ) = 0;
 
     virtual bool closeAllDocuments() = 0;
 
