@@ -23,6 +23,7 @@
 
 #include "backgroundparser.h"
 
+#include <QCoreApplication>
 #include <QList>
 #include <QMutex>
 #include <QMutexLocker>
@@ -811,6 +812,30 @@ QList< IndexedString > BackgroundParser::managedDocuments()
     return d->m_managed.keys();
 }
 
+
+bool BackgroundParser::waitForIdle() const
+{
+    QList<IndexedString> runningParseJobsUrls;
+    forever {
+        {
+            QMutexLocker lock(&d->m_mutex);
+            if (d->m_parseJobs.isEmpty()) {
+                qCDebug(LANGUAGE) << "All parse jobs done" << d->m_parseJobs.keys();
+                return true;
+            }
+
+            if (d->m_parseJobs.size() != runningParseJobsUrls.size()) {
+                runningParseJobsUrls = d->m_parseJobs.keys();
+                qCDebug(LANGUAGE) << "Waiting for background parser to get in idle state... -- the following parse jobs are still running:" << runningParseJobsUrls;
+            }
+        }
+
+        QCoreApplication::processEvents();
+        QThread::msleep(100);
+    }
+    return false;
+}
+
 DocumentChangeTracker* BackgroundParser::trackerForUrl(const KDevelop::IndexedString& url) const
 {
     if (url.isEmpty()) {
