@@ -69,6 +69,9 @@ int NormalDeclarationCompletionItem::argumentHintDepth() const
 
 QString NormalDeclarationCompletionItem::declarationName() const
 {
+  if (!m_declaration) {
+    return QStringLiteral("<unknown>");
+  }
   QString ret = m_declaration->identifier().toString();
   if (ret.isEmpty())
     return QStringLiteral("<unknown>");
@@ -104,7 +107,7 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::View* view, const KTe
 QWidget* NormalDeclarationCompletionItem::createExpandingWidget(const KDevelop::CodeCompletionModel* model) const
 {
   Q_UNUSED(model);
-  return 0;
+  return nullptr;
 }
 
 bool NormalDeclarationCompletionItem::createsExpandingWidget() const
