@@ -76,15 +76,17 @@ VariableDescription::VariableDescription(const DeclarationPointer& declaration)
     if (declaration)
     {
         name = declaration->identifier().toString();
-        type = declaration->abstractType()->toString();
+        if (auto abstractType = declaration->abstractType()) {
+            type = abstractType->toString();
+        }
     }
 
     access = accessPolicyName(declaration);
 }
 
 FunctionDescription::FunctionDescription()
+    : FunctionDescription::FunctionDescription({}, {}, {})
 {
-
 }
 
 FunctionDescription::FunctionDescription(const QString& name, const VariableDescriptionList& arguments,
@@ -92,11 +94,18 @@ FunctionDescription::FunctionDescription(const QString& name, const VariableDesc
 : name(name)
 , arguments(arguments)
 , returnArguments(returnArguments)
+, isConstructor(false)
+, isDestructor(false)
+, isVirtual(false)
+, isStatic(false)
+, isSlot(false)
+, isSignal(false)
+, isConst(false)
 {
-
 }
 
 FunctionDescription::FunctionDescription(const DeclarationPointer& declaration)
+    : FunctionDescription::FunctionDescription({}, {}, {})
 {
     DUChainReadLocker lock;
 
