@@ -70,7 +70,7 @@ void DumpDotGraphPrivate::addDeclaration(QTextStream& stream, Declaration* dec)
 
   m_hadObjects[dec] = true;
 
-  Declaration* declarationForDefinition = 0;
+  Declaration* declarationForDefinition = nullptr;
   if(dynamic_cast<FunctionDefinition*>(dec))
     declarationForDefinition = static_cast<FunctionDefinition*>(dec)->declaration(m_topContext);
 
