@@ -21,6 +21,8 @@
 #include <QTextDocument>
 #include <KLocalizedString>
 
+#include <qtcompat_p.h>
+
 #include "abstractdeclarationnavigationcontext.h"
 #include "abstractnavigationwidget.h"
 #include "usesnavigationcontext.h"
@@ -51,6 +53,8 @@ AbstractNavigationContext::AbstractNavigationContext( KDevelop::TopDUContextPoin
   : m_selectedLink(0), m_shorten(false), m_linkCount(-1), m_currentPositionLine(0),
     m_previousContext(previousContext), m_topContext(topContext)
 {
+  qRegisterMetaType<KTextEditor::Cursor>("KTextEditor::Cursor");
+  qRegisterMetaType<IDocumentation::Ptr>("IDocumentation::Ptr");
 }
 
 void AbstractNavigationContext::addExternalHtml( const QString& text )
@@ -160,7 +164,6 @@ NavigationContextPointer AbstractNavigationContext::execute(const NavigationActi
       qCDebug(LANGUAGE) << "Navigation-action has invalid declaration" << endl;
       return NavigationContextPointer(this);
   }
-  qRegisterMetaType<KTextEditor::Cursor>("KTextEditor::Cursor");
 
   switch( action.type ) {
     case NavigationAction::ExecuteKey:
@@ -182,7 +185,7 @@ NavigationContextPointer AbstractNavigationContext::execute(const NavigationActi
         browser->showUses(action.decl);
         return NavigationContextPointer(this);
       }
-      // fall-through
+      Q_FALLTHROUGH();
     }
     case NavigationAction::ShowUses:
       return registerChild(new UsesNavigationContext(action.decl.data(), this));
@@ -211,7 +214,9 @@ NavigationContextPointer AbstractNavigationContext::execute(const NavigationActi
       }
     case NavigationAction::ShowDocumentation: {
         auto doc = ICore::self()->documentationController()->documentationForDeclaration(action.decl.data());
-        ICore::self()->documentationController()->showDocumentation(doc);
+        // This is used to execute the slot delayed in the event-loop, so crashes are avoided
+        // which can happen e.g. due to focus change events resulting in tooltip destruction and thus this object
+        QMetaObject::invokeMethod(ICore::self()->documentationController(), "showDocumentation", Qt::QueuedConnection, Q_ARG(IDocumentation::Ptr, doc));
       }
       break;
   }
