@@ -20,6 +20,8 @@
 #include "safetycounter.h"
 #include "util/debug.h"
 
+#include <qtcompat_p.h>
+
 #include <QString>
 #include <QStringList>
 
@@ -50,7 +52,7 @@ int strip_impl(const T& str, T& from)
   }
 
   if( ip ) {
-    from = from.mid( ip );
+    from.remove(0, ip);
   }
   return s - from.length();
 }
@@ -99,10 +101,15 @@ T formatComment_impl(const T& comment)
 
     // remove common leading chars from the beginning of lines
     for( ; it != eit; ++it ) {
-        strip_impl<T>( "///", *it );
-        strip_impl<T>( "//", *it );
-        strip_impl<T>( "**", *it );
-        rStrip_impl<T>( "/**", *it );
+        // don't trigger repeated temporary allocations here
+        static const T tripleSlash("///");
+        static const T doubleSlash("//");
+        static const T doubleStar("**");
+        static const T slashDoubleStar("/**");
+        strip_impl( tripleSlash, *it );
+        strip_impl( doubleSlash, *it );
+        strip_impl( doubleStar, *it );
+        rStrip_impl( slashDoubleStar, *it );
     }
 
     foreach(const T& line, lines) {
@@ -165,6 +172,7 @@ int findClose( const QString& str , int pos )
       break;
     case '>':
       if( last == '-' ) break;
+      Q_FALLTHROUGH();
     case ')':
       case ']':
         case '}':
@@ -228,6 +236,7 @@ int findCommaOrEnd( const QString& str , int pos, QChar validEnd)
         case '>':
         if( validEnd != ' ' && validEnd != str[a] )
           continue;
+        Q_FALLTHROUGH();
     case ',':
       return a;
     }
@@ -276,18 +285,18 @@ QString reverse( const QString& str ) {
 
 ///@todo this hackery sucks
 QString escapeForBracketMatching(QString str) {
-  str.replace("<<", "$&");
-  str.replace(">>", "$$");
-  str.replace("\\\"", "$!");
-  str.replace("->", "$?");
+  str.replace(QStringLiteral("<<"), QStringLiteral("$&"));
+  str.replace(QStringLiteral(">>"), QStringLiteral("$$"));
+  str.replace(QStringLiteral("\\\""), QStringLiteral("$!"));
+  str.replace(QStringLiteral("->"), QStringLiteral("$?"));
   return str;
 }
 
 QString escapeFromBracketMatching(QString str) {
-  str.replace("$&", "<<");
-  str.replace("$$", ">>");
-  str.replace("$!", "\\\"");
-  str.replace("$?", "->");
+  str.replace(QStringLiteral("$&"), QStringLiteral("<<"));
+  str.replace(QStringLiteral("$$"), QStringLiteral(">>"));
+  str.replace(QStringLiteral("$!"), QStringLiteral("\\\""));
+  str.replace(QStringLiteral("$?"), QStringLiteral("->"));
   return str;
 }
 
@@ -380,7 +389,7 @@ QString clearComments( QString str, QChar replacement ) {
     else if (withoutStrings[pos + 1] == '*')
     {
       //CPP style comment
-      endCommentPos = withoutStrings.indexOf("*/", pos + 2);
+      endCommentPos = withoutStrings.indexOf(QStringLiteral("*/"), pos + 2);
       if (endCommentPos != -1)
         endCommentPos += 2;
 
