@@ -51,7 +51,7 @@ public:
   /// Copy constructor. \param rhs type to copy
   FunctionType(const FunctionType& rhs);
   /// Constructor using raw data. \param data internal data.
-  FunctionType(FunctionTypeData& data);
+  explicit FunctionType(FunctionTypeData& data);
   /// Destructor
   ~FunctionType();
 
@@ -103,11 +103,11 @@ public:
    */
   void removeArgument(int i);
 
-  virtual AbstractType* clone() const;
+  AbstractType* clone() const override;
 
-  virtual bool equals(const AbstractType* rhs) const;
+  bool equals(const AbstractType* rhs) const override;
 
-  virtual QString toString() const;
+  QString toString() const override;
 
   /**
    * This function creates a string that represents the requested part of
@@ -118,11 +118,11 @@ public:
    */
   virtual QString partToString( SignaturePart sigPart ) const;
 
-  virtual uint hash() const;
+  uint hash() const override;
 
-  virtual WhichType whichType() const;
+  WhichType whichType() const override;
 
-  virtual void exchangeTypes( TypeExchanger* exchanger );
+  void exchangeTypes( TypeExchanger* exchanger ) override;
 
   enum {
     Identity = 5
@@ -131,7 +131,7 @@ public:
   typedef FunctionTypeData Data;
 
 protected:
-  virtual void accept0 (TypeVisitor *v) const;
+  void accept0 (TypeVisitor *v) const override;
 
   TYPE_DECLARE_DATA(FunctionType)
 };
@@ -139,7 +139,7 @@ protected:
 template<>
 inline FunctionType* fastCast<FunctionType*>(AbstractType* from) {
   if(!from || from->whichType() != AbstractType::TypeFunction)
-    return 0;
+    return nullptr;
   else
     return static_cast<FunctionType*>(from);
 }
@@ -147,5 +147,3 @@ inline FunctionType* fastCast<FunctionType*>(AbstractType* from) {
 }
 
 #endif
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
