@@ -50,7 +50,7 @@ public:
   /**
    * Sets the base type of the pointer, ie. what type of data the pointer points to.
    *
-   * \param baseType the base type.
+   * \param type the base type.
    */
   void setBaseType(AbstractType::Ptr type);
 
@@ -61,17 +61,17 @@ public:
    */
   AbstractType::Ptr baseType () const;
 
-  virtual QString toString() const override;
+  QString toString() const override;
 
-  virtual uint hash() const override;
+  uint hash() const override;
 
-  virtual WhichType whichType() const override;
+  WhichType whichType() const override;
 
-  virtual AbstractType* clone() const override;
+  AbstractType* clone() const override;
 
-  virtual bool equals(const AbstractType* rhs) const override;
+  bool equals(const AbstractType* rhs) const override;
 
-  virtual void exchangeTypes( TypeExchanger* exchanger ) override;
+  void exchangeTypes( TypeExchanger* exchanger ) override;
 
   enum {
     Identity = 3
@@ -80,7 +80,7 @@ public:
   typedef PointerTypeData Data;
 
 protected:
-  virtual void accept0 (TypeVisitor *v) const override;
+  void accept0 (TypeVisitor *v) const override;
 
   TYPE_DECLARE_DATA(PointerType)
 };
@@ -88,7 +88,7 @@ protected:
 template<>
 inline PointerType* fastCast<PointerType*>(AbstractType* from) {
   if(!from || from->whichType() != AbstractType::TypePointer)
-    return 0;
+    return nullptr;
   else
     return static_cast<PointerType*>(from);
 }
