@@ -97,26 +97,19 @@ DeclarationContext::DeclarationContext( const IndexedDeclaration& declaration, c
         : DUContextContext(context), d( new Private( declaration, use ) )
 {}
 
-DeclarationContext::DeclarationContext(KTextEditor::View* view, KTextEditor::Cursor position) : DUContextContext(IndexedDUContext())
+DeclarationContext::DeclarationContext(KTextEditor::View* view, const KTextEditor::Cursor& position) : DUContextContext(IndexedDUContext())
 {
     const QUrl& url = view->document()->url();
-    const KTextEditor::Cursor pos = KTextEditor::Cursor(position);
     DUChainReadLocker lock;
-    DocumentRange useRange = DocumentRange(IndexedString(url), DUChainUtils::itemRangeUnderCursor(url, pos));
-    Declaration* declaration = DUChainUtils::itemUnderCursor(url, pos);
+    DUChainUtils::ItemUnderCursor item = DUChainUtils::itemUnderCursor(url, position);
+    DocumentRange useRange = DocumentRange(IndexedString(url), item.range);
+    Declaration* declaration = item.declaration;
     IndexedDeclaration indexed;
     if ( declaration ) {
         indexed = IndexedDeclaration(declaration);
     }
-    IndexedDUContext context;
-    TopDUContext* topContext = DUChainUtils::standardContextForUrl(view->document()->url());
-    if(topContext) {
-        DUContext* specific = topContext->findContextAt(CursorInRevision(pos.line(), pos.column()));
-        if(specific)
-            context = IndexedDUContext(specific);
-    }
     d = new Private(declaration, useRange);
-    setContext(context);
+    setContext(IndexedDUContext(item.context));
 }
 
 DeclarationContext::~DeclarationContext()
