@@ -98,10 +98,12 @@ void AppWizardPlugin::slotNewProject()
 
             KConfig templateConfig(dlg.appInfo().appTemplate);
             KConfigGroup general(&templateConfig, "General");
-            QString file = general.readEntry("ShowFilesAfterGeneration");
-            if (!file.isEmpty())
-            {
-                file = KMacroExpander::expandMacros(file, m_variables);
+            const QStringList fileArgs = general.readEntry("ShowFilesAfterGeneration").split(QLatin1Char(','), QString::SkipEmptyParts);
+            for (const auto& fileArg : fileArgs) {
+                QString file = KMacroExpander::expandMacros(fileArg.trimmed(), m_variables);
+                if (QDir::isRelativePath(file)) {
+                    file = m_variables[QStringLiteral("PROJECTDIR")] + QLatin1Char('/') + file;
+                }
                 core()->documentController()->openDocument(QUrl::fromUserInput(file));
             }
         } else {
@@ -209,7 +211,7 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
 {
     QFileInfo templateInfo(info.appTemplate);
     if (!templateInfo.exists()) {
-        qWarning() << "Project app template does not exist:" << info.appTemplate;
+        qCWarning(PLUGIN_APPWIZARD) << "Project app template does not exist:" << info.appTemplate;
         return QString();
     }
 
@@ -225,7 +227,7 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
     }
 
     if(templateArchive.isEmpty()) {
-        qWarning() << "Template name does not exist in the template list";
+        qCWarning(PLUGIN_APPWIZARD) << "Template name does not exist in the template list";
         return QString();
     }
 
@@ -273,8 +275,42 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
             }
         }
 
-        if ( !unpackArchive( arch->directory(), unpackDir ) )
-        {
+        // estimate metadata files which should not be copied
+        QStringList metaDataFileNames;
+
+        // try by same name
+        const KArchiveEntry *templateEntry =
+            arch->directory()->entry(templateName + QLatin1String(".kdevtemplate"));
+
+        // but could be different name, if e.g. downloaded, so make a guess
+        if (!templateEntry || !templateEntry->isFile()) {
+            for (const auto& entryName : arch->directory()->entries()) {
+                if (entryName.endsWith(QLatin1String(".kdevtemplate"))) {
+                    templateEntry = arch->directory()->entry(entryName);
+                    break;
+                }
+            }
+        }
+
+        if (templateEntry && templateEntry->isFile()) {
+            metaDataFileNames << templateEntry->name();
+
+            // check if a preview file is to be ignored
+            const KArchiveFile *templateFile = static_cast<const KArchiveFile*>(templateEntry);
+            QTemporaryDir temporaryDir;
+            templateFile->copyTo(temporaryDir.path());
+
+            KConfig config(temporaryDir.path() + QLatin1Char('/') + templateEntry->name());
+            KConfigGroup group(&config, "General");
+            if (group.hasKey("Icon")) {
+                const KArchiveEntry* iconEntry = arch->directory()->entry(group.readEntry("Icon"));
+                if (iconEntry && iconEntry->isFile()) {
+                    metaDataFileNames << iconEntry->name();
+                }
+            }
+        }
+
+        if (!unpackArchive(arch->directory(), unpackDir, metaDataFileNames)) {
             QString errorMsg = i18n("Could not create new project");
             vcsError(errorMsg, tmpdir, QUrl::fromLocalFile(unpackDir));
             return QString();
@@ -332,8 +368,8 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
 
     qCDebug(PLUGIN_APPWIZARD) << "Returning" << projectFileName << QFileInfo::exists( projectFileName ) ;
 
-    if( ! QFileInfo::exists( projectFileName ) )
-    {
+    const QFileInfo projectFileInfo(projectFileName);
+    if (!projectFileInfo.exists()) {
         qCDebug(PLUGIN_APPWIZARD) << "creating .kdev4 file";
         KSharedConfigPtr cfg = KSharedConfig::openConfig( projectFileName, KConfig::SimpleConfig );
         KConfigGroup project = cfg->group( "Project" );
@@ -358,10 +394,21 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
         qCDebug(PLUGIN_APPWIZARD) << "kdev4 file contents:" << project2.readEntry("Name", "") << project2.readEntry("Manager", "" );
     }
 
+    // create developer .kde4 file
+    const QString developerProjectFileName = projectFileInfo.canonicalPath() + QLatin1String("/.kdev4/") + projectFileInfo.fileName();
+
+    qCDebug(PLUGIN_APPWIZARD) << "creating developer .kdev4 file:" << developerProjectFileName;
+    KSharedConfigPtr developerCfg = KSharedConfig::openConfig(developerProjectFileName, KConfig::SimpleConfig);
+    KConfigGroup developerProjectGroup = developerCfg->group("Project");
+    developerProjectGroup.writeEntry("VersionControlSupport", info.vcsPluginName);
+    developerProjectGroup.sync();
+
+    developerCfg->sync();
+
     return projectFileName;
 }
 
-bool AppWizardPlugin::unpackArchive(const KArchiveDirectory *dir, const QString &dest)
+bool AppWizardPlugin::unpackArchive(const KArchiveDirectory* dir, const QString& dest, const QStringList& skipList)
 {
     qCDebug(PLUGIN_APPWIZARD) << "unpacking dir:" << dir->name() << "to" << dest;
     const QStringList entries = dir->entries();
@@ -379,8 +426,10 @@ bool AppWizardPlugin::unpackArchive(const KArchiveDirectory *dir, const QString
 
     foreach (const QString& entry, entries)
     {
-        if (entry.endsWith(QLatin1String(".kdevtemplate")))
+        if (skipList.contains(entry)) {
             continue;
+        }
+
         if (dir->entry(entry)->isDirectory())
         {
             const KArchiveDirectory *file = (KArchiveDirectory *)dir->entry(entry);
