@@ -105,10 +105,10 @@ void ExternalScriptView::validateActions()
 
 void ExternalScriptView::contextMenu( const QPoint& pos )
 {
-  QMenu menu;
+  QMenu menu(this);
   menu.addActions( actions() );
 
-  menu.exec( scriptTree->mapToGlobal( pos ) );
+  menu.exec(scriptTree->viewport()->mapToGlobal(pos));
 }
 
 bool ExternalScriptView::eventFilter( QObject* obj, QEvent* e )
