@@ -141,11 +141,14 @@ void OverridesPage::addBaseClasses(const QList<DeclarationPointer>& directBases,
     DUChainReadLocker lock;
 
     foreach(const DeclarationPointer& baseClass, allBases) {
-        DUContext* context = baseClass->internalContext();
-
         QTreeWidgetItem* classItem = new QTreeWidgetItem(overrideTree(), QStringList() << baseClass->qualifiedIdentifier().toString());
         classItem->setIcon(ClassOrFunctionColumn, DUChainUtils::iconForDeclaration(baseClass.data()));
 
+        DUContext* context = baseClass->internalContext();
+        if (!context) {
+            continue;
+        }
+
         //For this internal context get all the function declarations inside the class
         foreach (Declaration * childDeclaration, context->localDeclarations()) {
             if (AbstractFunctionDeclaration * func = dynamic_cast<AbstractFunctionDeclaration*>(childDeclaration))
