@@ -41,6 +41,7 @@ public:
     QList<SourceFileTemplate::ConfigOption> entries;
     QHash<QString, QWidget*> controls;
     QHash<QString, QByteArray> typeProperties;
+    QList<QWidget*> groupBoxes;
 };
 
 TemplateOptionsPage::TemplateOptionsPage(QWidget* parent, Qt::WindowFlags f)
@@ -59,15 +60,26 @@ TemplateOptionsPage::~TemplateOptionsPage()
 
 void TemplateOptionsPage::load(const SourceFileTemplate& fileTemplate, TemplateRenderer* renderer)
 {
-    d->entries.clear();
+    // TODO: keep any old changed values, as it comes by surprise to have them lost
+    // when going back and forward
 
-    QLayout* layout = new QVBoxLayout();
+    // clear anything as there is on reentering the page
+    d->entries.clear();
+    d->controls.clear();
+    // clear any old option group boxes & the base layout
+    qDeleteAll(d->groupBoxes);
+    d->groupBoxes.clear();
+    delete layout();
+
+    QVBoxLayout* layout = new QVBoxLayout();
     QHash<QString, QList<SourceFileTemplate::ConfigOption> > options = fileTemplate.customOptions(renderer);
     QHash<QString, QList<SourceFileTemplate::ConfigOption> >::const_iterator it;
 
     for (it = options.constBegin(); it != options.constEnd(); ++it)
     {
         QGroupBox* box = new QGroupBox(this);
+        d->groupBoxes.append(box);
+
         box->setTitle(it.key());
 
         QFormLayout* formLayout = new QFormLayout;
@@ -75,7 +87,6 @@ void TemplateOptionsPage::load(const SourceFileTemplate& fileTemplate, TemplateR
         d->entries << it.value();
         foreach (const SourceFileTemplate::ConfigOption& entry, it.value())
         {
-            QLabel* label = new QLabel(entry.label, box);
             QWidget* control = nullptr;
             const QString type = entry.type;
             if (type == QLatin1String("String"))
@@ -99,8 +110,9 @@ void TemplateOptionsPage::load(const SourceFileTemplate& fileTemplate, TemplateR
             else if (type == QLatin1String("Bool"))
             {
                 bool checked = (QString::compare(entry.value.toString(), QStringLiteral("true"), Qt::CaseInsensitive) == 0);
-                QCheckBox* checkBox = new QCheckBox(entry.label, box);
+                QCheckBox* checkBox = new QCheckBox(box);
                 checkBox->setCheckState(checked ? Qt::Checked : Qt::Unchecked);
+                control = checkBox;
             }
             else
             {
@@ -108,6 +120,7 @@ void TemplateOptionsPage::load(const SourceFileTemplate& fileTemplate, TemplateR
             }
             if (control)
             {
+                QLabel* label = new QLabel(entry.label, box);
                 formLayout->addRow(label, control);
                 d->controls.insert(entry.name, control);
             }
@@ -116,6 +129,9 @@ void TemplateOptionsPage::load(const SourceFileTemplate& fileTemplate, TemplateR
         box->setLayout(formLayout);
         layout->addWidget(box);
     }
+
+    layout->addStretch();
+
     setLayout(layout);
 }
 
