@@ -21,9 +21,9 @@
 #include "gitmessagehighlighter.h"
 
 #include <QtCore/QString>
-#include <QtGui/QTextCharFormat>
-#include <QtGui/QTextEdit>
-#include <KDE/KLocalizedString>
+#include <QTextCharFormat>
+#include <QTextEdit>
+#include <KLocalizedString>
 
 /// Recomended summary limit from http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html
 static const int summarySoftLimit = 50;
@@ -113,4 +113,3 @@ void GitMessageHighlighter::highlightBlock(const QString& text)
     setCurrentBlockState(blockState);
 }
 
-#include "gitmessagehighlighter.moc"
