@@ -13,6 +13,8 @@
 
 #include "grepdialog.h"
 
+#include <algorithm>
+
 #include <QDialogButtonBox>
 #include <QDir>
 #include <QFileDialog>
@@ -199,7 +201,7 @@ void GrepDialog::addUrlToMenu(QMenu* menu, const QUrl& url)
     connect(action, &QAction::triggered, this, &GrepDialog::synchronizeDirActionTriggered);
 }
 
-void GrepDialog::addStringToMenu(QMenu* menu, QString string)
+void GrepDialog::addStringToMenu(QMenu* menu, const QString& string)
 {
     QAction* action = menu->addAction(string);
     action->setData(QVariant(string));
@@ -215,7 +217,7 @@ void GrepDialog::synchronizeDirActionTriggered(bool)
 
 QMenu* GrepDialog::createSyncButtonMenu()
 {
-    QMenu* ret = new QMenu;
+    QMenu* ret = new QMenu(this);
 
     QSet<Path> hadUrls;
 
@@ -240,13 +242,22 @@ QMenu* GrepDialog::createSyncButtonMenu()
         }
     }
 
+    QVector<QUrl> otherProjectUrls;
     foreach(IProject* project, m_plugin->core()->projectController()->projects())
     {
         if (!hadUrls.contains(project->path())) {
-            addUrlToMenu(ret, project->path().toUrl());
+            otherProjectUrls.append(project->path().toUrl());
         }
     }
 
+    // sort the remaining project URLs alphabetically
+    std::sort(otherProjectUrls.begin(), otherProjectUrls.end());
+    foreach(const QUrl& url, otherProjectUrls)
+    {
+        addUrlToMenu(ret, url);
+    }
+
+    ret->addSeparator();
     addStringToMenu(ret, allOpenFilesString());
     addStringToMenu(ret, allOpenProjectsString());
     return ret;
