@@ -24,7 +24,7 @@ Q_LOGGING_CATEGORY(PLUGIN_KONSOLE, "kdevplatform.plugins.konsole")
 
 QObject* createKonsoleView( QWidget*, QObject* op, const QVariantList& args)
 {
-    KService::Ptr service = KService::serviceByDesktopName("konsolepart");
+    KService::Ptr service = KService::serviceByDesktopName(QStringLiteral("konsolepart"));
     KPluginFactory* factory = nullptr;
     if (service) {
         factory = KPluginLoader(*service.data()).factory();
@@ -41,17 +41,17 @@ class KDevKonsoleViewFactory: public KDevelop::IToolViewFactory{
 public:
     KDevKonsoleViewFactory(KDevKonsoleViewPlugin *plugin):
         mplugin(plugin) {}
-    virtual QWidget* create(QWidget *parent = 0) override
+    QWidget* create(QWidget *parent = nullptr) override
     {
         return new KDevKonsoleView(mplugin, parent);
     }
-    virtual Qt::DockWidgetArea defaultPosition() override
+    Qt::DockWidgetArea defaultPosition() override
     {
         return Qt::BottomDockWidgetArea;
     }
-    virtual QString id() const override
+    QString id() const override
     {
-        return "org.kdevelop.KonsoleView";
+        return QStringLiteral("org.kdevelop.KonsoleView");
     }
 private:
     KDevKonsoleViewPlugin *mplugin;
@@ -62,8 +62,10 @@ KDevKonsoleViewPlugin::KDevKonsoleViewPlugin( KPluginFactory* konsoleFactory, QO
     , m_konsoleFactory(konsoleFactory)
     , m_viewFactory(konsoleFactory ? new KDevKonsoleViewFactory(this) : nullptr)
 {
-    if (m_viewFactory) {
-        core()->uiController()->addToolView("Konsole", m_viewFactory);
+    if(!m_viewFactory) {
+      setErrorDescription(i18n("Failed to load 'konsolepart' plugin"));
+    } else {
+        core()->uiController()->addToolView(QStringLiteral("Konsole"), m_viewFactory);
     }
 }
 
@@ -74,16 +76,6 @@ void KDevKonsoleViewPlugin::unload()
     }
 }
 
-bool KDevKonsoleViewPlugin::hasError() const
-{
-    return !m_viewFactory;
-}
-
-QString KDevKonsoleViewPlugin::errorDescription() const
-{
-    return !m_viewFactory ? i18n("Failed to load 'konsolepart' plugin") : QString();
-}
-
 KPluginFactory* KDevKonsoleViewPlugin::konsoleFactory() const
 {
     return m_konsoleFactory;
