@@ -28,7 +28,7 @@
 
 LocalPatchSource::LocalPatchSource()
     : m_applied(false)
-    , m_widget(0)
+    , m_widget(nullptr)
 {
 }
 
@@ -89,7 +89,7 @@ void LocalPatchSource::update()
 void LocalPatchSource::createWidget()
 {
     delete m_widget;
-    m_widget = new LocalPatchWidget(this, 0);
+    m_widget = new LocalPatchWidget(this, nullptr);
 }
 
 QWidget* LocalPatchSource::customWidget() const
@@ -126,5 +126,5 @@ void LocalPatchWidget::updatePatchFromEdit()
     m_lpatch->setCommand(m_ui->command->text());
     m_lpatch->setFilename(m_ui->filename->url());
     m_lpatch->setBaseDir(m_ui->baseDir->url());
-    m_lpatch->setAlreadyApplied(m_ui->applied->checkState() == Qt::Checked );
+    m_lpatch->setAlreadyApplied(m_ui->applied->checkState() == Qt::Checked);
 }
