@@ -22,10 +22,18 @@
 
 #include <interfaces/itoolviewactionlistener.h>
 
-#include <QMainWindow>
+#include <QWidget>
 
 class ProblemTreeView;
 
+class KActionMenu;
+
+class QAction;
+class QActionGroup;
+class QLineEdit;
+class QMenu;
+class QTabWidget;
+
 namespace KDevelop
 {
 struct ModelData;
@@ -33,22 +41,19 @@ struct ModelData;
 /**
  * @brief Provides a tabbed view for models in the ProblemModelSet.
  *
+ *
  * Also provides a toolbar for actions for the models and shows the number of messages in each tab's text.
  * When the load() method is called it looks up the models in the ProblemModelSet.
  * For each model it creates a treeview, which is then added to the tabbed view and a new tab.
  * The tab's text will be the name of the model + the number of items in the treeview.
- *
- * TODO: According to apol this should NOT be a QMainWindow,
- * because updating the widget's actions should be sufficient to update the
- * toolbar of the toolviiew
  */
-class ProblemsView : public QMainWindow, public IToolViewActionListener
+class ProblemsView : public QWidget, public IToolViewActionListener
 {
     Q_OBJECT
     Q_INTERFACES(KDevelop::IToolViewActionListener)
 
 public:
-    explicit ProblemsView(QWidget* parent = NULL);
+    explicit ProblemsView(QWidget* parent = nullptr);
     ~ProblemsView() override;
 
     /// Load all the current models and create tabs for them
@@ -59,7 +64,7 @@ public Q_SLOTS:
     void onModelAdded(const ModelData& data);
 
     /// Triggered when a model is removed from the ModelSet
-    void onModelRemoved(const QString& name);
+    void onModelRemoved(const QString& id);
 
     /// Triggered when the user (or program) selects a new tab
     void onCurrentChanged(int idx);
@@ -67,23 +72,46 @@ public Q_SLOTS:
     /// Triggered when a view changes (happens when the model data changes)
     void onViewChanged();
 
+    /// Open tab for selected model
+    void showModel(const QString& id);
+
     void selectNextItem() override;
     void selectPreviousItem() override;
 
 private:
     ProblemTreeView* currentView() const;
 
+    void setupActions();
+    void updateActions();
+
+    void handleSeverityActionToggled();
+    void setScope(int scope);
+
     /// Create a view for the model and add to the tabbed widget
     void addModel(const ModelData& data);
 
-    /// Update the toolbar with the widget's actions
-    void updateToolBar();
-
     /// Update the tab's text (name + number of problems in that tab)
     void updateTab(int idx, int rows);
 
-    QToolBar* m_toolBar;
     QTabWidget* m_tabWidget;
+
+    KActionMenu* m_scopeMenu = nullptr;
+    KActionMenu* m_groupingMenu = nullptr;
+    QAction* m_fullUpdateAction = nullptr;
+    QAction* m_showImportsAction = nullptr;
+    QActionGroup* m_severityActions = nullptr;
+    QAction* m_currentDocumentAction = nullptr;
+    QAction* m_showAllAction = nullptr;
+    QAction* m_errorSeverityAction = nullptr;
+    QAction* m_warningSeverityAction = nullptr;
+    QAction* m_hintSeverityAction = nullptr;
+
+    void setFilter(const QString& filterText);
+    void setFilter(const QString& filterText, int tabIdx);
+
+    QLineEdit* m_filterEdit;
+    int m_prevTabIdx;
+    QVector<ModelData> m_models;
 };
 }
 
