@@ -379,18 +379,15 @@ void ProjectTreeView::popupContextMenu( const QPoint &pos )
 
     if ( !itemlist.isEmpty() && itemlist.size() == 1 && itemlist[0]->folder() && !itemlist[0]->folder()->parent() )
     {
-        QAction* projectConfig = new QAction(i18n("Open Configuration..."), this);
+        QAction* projectConfig = new QAction(i18n("Open Configuration..."), &menu);
         projectConfig->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
         connect( projectConfig, &QAction::triggered, this, &ProjectTreeView::openProjectConfig );
         projectActions << projectConfig;
     }
     popupContextMenu_appendActions(menu, projectActions);
 
-    if(!itemlist.isEmpty())
-        KDevelop::populateParentItemsMenu(itemlist.front(), &menu);
-
     if ( !menu.isEmpty() ) {
-        menu.exec( mapToGlobal( pos ) );
+        menu.exec(viewport()->mapToGlobal(pos));
     }
 }
 
@@ -436,11 +433,6 @@ void ProjectTreeView::rowsInserted( const QModelIndex& parent, int start, int en
 {
     QTreeView::rowsInserted( parent, start, end );
 
-    // automatically select row if there is only one
-    if ( model()->rowCount() == 1 ) {
-        selectionModel()->select( model()->index( 0, 0 ), QItemSelectionModel::Select );
-    }
-
     if ( !parent.model() ) {
         for ( const auto& project: selectedProjects() ) {
             restoreState( project->project() );
@@ -450,11 +442,6 @@ void ProjectTreeView::rowsInserted( const QModelIndex& parent, int start, int en
 
 void ProjectTreeView::rowsAboutToBeRemoved( const QModelIndex& parent, int start, int end )
 {
-    // automatically select row if there is only one
-    if ( model()->rowCount() == 1 ) {
-        selectionModel()->select( model()->index( 0, 0 ), QItemSelectionModel::Select );
-    }
-
     if ( !parent.model() ) {
         for ( const auto& project: selectedProjects() ) {
             saveState( project->project() );
@@ -477,8 +464,8 @@ bool ProjectTreeView::event(QEvent* event)
 {
     if(event->type()==QEvent::ToolTip)
     {
-        QPoint p = mapFromGlobal(QCursor::pos());
-        QModelIndex idxView = indexAt(p);
+        QHelpEvent* helpEvent = static_cast<QHelpEvent*>(event);
+        QModelIndex idxView = indexAt(helpEvent->pos());
 
         ProjectBaseItem* it = idxView.data(ProjectModel::ProjectItemRole).value<ProjectBaseItem*>();
         QModelIndex idx;
@@ -500,7 +487,7 @@ bool ProjectTreeView::event(QEvent* event)
                 QWidget* navigationWidget = top->createNavigationWidget();
                 if( navigationWidget )
                 {
-                    m_tooltip = new KDevelop::NavigationToolTip(this, mapToGlobal(p) + QPoint(40, 0), navigationWidget);
+                    m_tooltip = new KDevelop::NavigationToolTip(this, helpEvent->globalPos() + QPoint(40, 0), navigationWidget);
                     m_tooltip->resize( navigationWidget->sizeHint() + QSize(10, 10) );
                     qCDebug(PLUGIN_PROJECTMANAGERVIEW) << "tooltip size" << m_tooltip->size();
                     ActiveToolTip::showToolTip(m_tooltip);
