@@ -137,7 +137,7 @@ QWidget* ProjectFileData::expandingWidget() const
     QList<TopDUContext*> contexts = DUChain::self()->chainsForDocument(url);
 
     ///Pick a non-proxy context
-    TopDUContext* chosen = 0;
+    TopDUContext* chosen = nullptr;
     foreach( TopDUContext* ctx, contexts ) {
         if( !(ctx->parsingEnvironmentFile() && ctx->parsingEnvironmentFile()->isProxyContext()) ) {
             chosen = ctx;
@@ -145,10 +145,10 @@ QWidget* ProjectFileData::expandingWidget() const
     }
 
     if( chosen ) {
-        return chosen->createNavigationWidget(0, 0,
+        return chosen->createNavigationWidget(nullptr, nullptr,
             "<small><small>"
             + i18nc("%1: project name", "Project %1", project())
-            + "</small></small>");
+            + "</small></small><br/>");
     } else {
         QTextBrowser* ret = new QTextBrowser();
         ret->resize(400, 100);
@@ -159,7 +159,7 @@ QWidget* ProjectFileData::expandingWidget() const
         return ret;
     }
 
-    return 0;
+    return nullptr;
 }
 
 QIcon ProjectFileData::icon() const
@@ -194,6 +194,11 @@ QString ProjectFileData::project() const
     }
 }
 
+Path ProjectFileData::projectPath() const
+{
+    return m_file.projectPath;
+}
+
 BaseFileDataProvider::BaseFileDataProvider()
 {
 }
