@@ -124,7 +124,8 @@ Path findProjectForForPath(const IndexedString& path)
 }
 
 ProjectItemDataProvider::ProjectItemDataProvider( KDevelop::IQuickOpen* quickopen )
-: m_quickopen(quickopen)
+    : m_itemTypes(NoItems)
+    , m_quickopen(quickopen)
 {
 }
 
@@ -200,15 +201,6 @@ void ProjectItemDataProvider::setFilterText( const QString& text )
     std::sort(m_filteredItems.begin(), m_filteredItems.end(), ClosestMatchToText(heights));
 }
 
-QList<KDevelop::QuickOpenDataPointer> ProjectItemDataProvider::data( uint start, uint end ) const
-{
-    QList<KDevelop::QuickOpenDataPointer> ret;
-    for(uint a = start; a < end; ++a) {
-        ret << data(a);
-    }
-    return ret;
-}
-
 KDevelop::QuickOpenDataPointer ProjectItemDataProvider::data( uint pos ) const
 {
     //Check whether this position falls into an appended item-list, else apply the offset
