@@ -31,9 +31,9 @@ using namespace KDevelop;
 
 QuickOpenTestBase::QuickOpenTestBase(Core::Setup setup_, QObject* parent)
 : QObject(parent)
-, core(0)
+, core(nullptr)
 , setup(setup_)
-, projectController(0)
+, projectController(nullptr)
 {
     qRegisterMetaType<QModelIndex>("QModelIndex");
 }
