@@ -158,6 +158,8 @@ OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
         filterInput->setToolTip(i18n("Enter a wild card string to filter the output view"));
         filterAction = new QWidgetAction(this);
         filterAction->setDefaultWidget(filterInput);
+        filterAction->setText(filterInput->placeholderText());
+        connect(filterAction, &QAction::triggered, this, [this]() {filterInput->setFocus();});
         addAction(filterAction);
 
         connect(filterInput, &QLineEdit::textEdited,
@@ -604,6 +606,7 @@ void OutputWidget::copySelection()
     Q_FOREACH( const QModelIndex& index, indexes) {
       content += index.data().toString() + '\n';
     }
+    content.chop(1);
     cb->setText(content);
 }
 
@@ -668,8 +671,12 @@ void OutputWidget::updateFilter(int index)
 
 void OutputWidget::setTitle(int outputId, const QString& title)
 {
-    if( data->type & KDevelop::IOutputView::MultipleView ) {
-        tabwidget->setTabText(outputId - 1, title);
+    QTreeView* view = views.value(outputId, nullptr);
+    if(view && (data->type & KDevelop::IOutputView::MultipleView)) {
+        int idx = tabwidget->indexOf(view);
+        if (idx >= 0) {
+            tabwidget->setTabText(idx, title);
+        }
     }
 }
 
