@@ -23,10 +23,7 @@
 
 #include <QMutexLocker>
 
-#include <kdebug.h>
-#include <klocale.h>
-
-#include <ThreadWeaver.h>
+#include <KLocalizedString>
 
 #include "kdevsvncpp/client.hpp"
 #include "kdevsvncpp/path.hpp"
@@ -38,16 +35,16 @@ SvnInternalRemoveJob::SvnInternalRemoveJob( SvnJobBase* parent )
 {
 }
 
-void SvnInternalRemoveJob::run()
+void SvnInternalRemoveJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread* /*thread*/)
 {
     initBeforeRun();
 
     svn::Client cli(m_ctxt);
     std::vector<svn::Path> targets;
-    KUrl::List l = locations();
-    foreach( const KUrl &url, l )
+    QList<QUrl> l = locations();
+    foreach( const QUrl &url, l )
     {
-        QByteArray ba = url.toLocalFile( KUrl::RemoveTrailingSlash ).toUtf8();
+        QByteArray ba = url.toString( QUrl::PreferLocalFile | QUrl::StripTrailingSlash ).toUtf8();
         targets.push_back( svn::Path( ba.data() ) );
     }
     try
@@ -56,7 +53,7 @@ void SvnInternalRemoveJob::run()
 
     }catch( svn::ClientException ce )
     {
-        kDebug(9510) << "Exception while removing files: "
+        qCDebug(PLUGIN_SVN) << "Exception while removing files: "
                 << m_locations
                 << QString::fromUtf8( ce.message() );
         setErrorMessage( QString::fromUtf8( ce.message() ) );
@@ -64,35 +61,34 @@ void SvnInternalRemoveJob::run()
     }
 }
 
-void SvnInternalRemoveJob::setLocations( const KUrl::List& urls )
+void SvnInternalRemoveJob::setLocations( const QList<QUrl>& urls )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_locations = urls;
 }
 
-KUrl::List SvnInternalRemoveJob::locations() const
+QList<QUrl> SvnInternalRemoveJob::locations() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_locations;
 }
 
 void SvnInternalRemoveJob::setForce( bool force )
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     m_force = force;
 }
 
 bool SvnInternalRemoveJob::force() const
 {
-    QMutexLocker l( m_mutex );
+    QMutexLocker l( &m_mutex );
     return m_force;
 }
 
 SvnRemoveJob::SvnRemoveJob( KDevSvnPlugin* parent )
-    : SvnJobBase( parent, KDevelop::OutputJob::Silent )
+    : SvnJobBaseImpl( parent, KDevelop::OutputJob::Silent )
 {
     setType( KDevelop::VcsJob::Add );
-    m_job = new SvnInternalRemoveJob( this );
     setObjectName(i18n("Subversion Remove"));
 }
 
@@ -103,36 +99,23 @@ QVariant SvnRemoveJob::fetchResults()
 
 void SvnRemoveJob::start()
 {
-    if( m_job->locations().isEmpty() )
-    {
-        internalJobFailed( m_job );
+    if( m_job->locations().isEmpty() ) {
+        internalJobFailed();
         setErrorText( i18n( "Not enough information to execute remove job" ) );
-    }else
-    {
-        kDebug(9510) << "removing urls:" << m_job->locations();
-        ThreadWeaver::Weaver::instance()->enqueue( m_job );
+    } else {
+        qCDebug(PLUGIN_SVN) << "removing urls:" << m_job->locations();
+        startInternalJob();
     }
 }
 
-SvnInternalJobBase* SvnRemoveJob::internalJob() const
-{
-    return m_job;
-}
-
-void SvnRemoveJob::setLocations( const KUrl::List& urls )
+void SvnRemoveJob::setLocations( const QList<QUrl>& urls )
 {
     if( status() == KDevelop::VcsJob::JobNotStarted )
         m_job->setLocations( urls );
 }
 
-
 void SvnRemoveJob::setForce( bool force )
 {
     if( status() == KDevelop::VcsJob::JobNotStarted )
         m_job->setForce( force );
 }
-
-#include "svnremovejob.moc"
-#include "svnremovejob_p.moc"
-
-
