@@ -69,7 +69,7 @@ Declaration* definitionForCursorDeclaration(const KTextEditor::Cursor& cursor, c
             return definition;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 QString findSwitchCandidate(const QUrl& docUrl)
@@ -94,10 +94,10 @@ QString findSwitchCandidate(const QUrl& docUrl)
 K_PLUGIN_FACTORY_WITH_JSON(SwitchToBuddyPluginFactory, "kdevswitchtobuddy.json", registerPlugin<SwitchToBuddyPlugin>(); )
 
 SwitchToBuddyPlugin::SwitchToBuddyPlugin ( QObject* parent, const QVariantList& )
-    : IPlugin ( "kdevswitchtobuddy", parent )
-    , m_signalMapper(0)
+    : IPlugin ( QStringLiteral("kdevswitchtobuddy"), parent )
+    , m_signalMapper(nullptr)
 {
-    setXMLFile("kdevswitchtobuddy.rc");
+    setXMLFile(QStringLiteral("kdevswitchtobuddy.rc"));
 }
 
 SwitchToBuddyPlugin::~SwitchToBuddyPlugin()
@@ -147,10 +147,28 @@ void SwitchToBuddyPlugin::createActionsForMainWindow(Sublime::MainWindow* /*wind
 {
     xmlFile = this->xmlFile();
 
-    QAction* switchDefinitionDeclaration = actions.addAction("switch_definition_declaration");
-    switchDefinitionDeclaration->setText( i18n("&Switch Definition/Declaration") );
-    actions.setDefaultShortcut( switchDefinitionDeclaration, Qt::CTRL | Qt::SHIFT | Qt::Key_C );
+    QAction* switchDefinitionDeclaration = actions.addAction(QStringLiteral("switch_definition_declaration"));
+    switchDefinitionDeclaration->setText(i18n("&Switch Definition/Declaration"));
+    actions.setDefaultShortcut(switchDefinitionDeclaration, Qt::CTRL | Qt::SHIFT | Qt::Key_C);
     connect(switchDefinitionDeclaration, &QAction::triggered, this, &SwitchToBuddyPlugin::switchDefinitionDeclaration);
+
+    QAction* switchHeaderSource = actions.addAction(QStringLiteral("switch_header_source"));
+    switchHeaderSource->setText(i18n("Switch Header/Source"));
+    actions.setDefaultShortcut(switchHeaderSource, Qt::CTRL | Qt::Key_Slash);
+    connect(switchHeaderSource, &QAction::triggered, this, &SwitchToBuddyPlugin::switchHeaderSource);
+}
+
+void SwitchToBuddyPlugin::switchHeaderSource()
+{
+    qCDebug(PLUGIN_SWITCHTOBUDDY) << "switching header/source";
+
+    auto doc = ICore::self()->documentController()->activeDocument();
+    if (!doc)
+        return;
+
+    QString buddyUrl = findSwitchCandidate(doc->url());
+    if (!buddyUrl.isEmpty())
+        switchToBuddy(buddyUrl);
 }
 
 void SwitchToBuddyPlugin::switchToBuddy(const QString& url)
@@ -206,7 +224,7 @@ void SwitchToBuddyPlugin::switchDefinitionDeclaration()
 
     bool wasSignal = false;
     if (standardCtx) {
-        Declaration* definition = 0;
+        Declaration* definition = nullptr;
 
         DUContext* ctx = standardCtx->findContext(standardCtx->transformToLocalRevision(cursor));
         if (!ctx) {
@@ -229,7 +247,7 @@ void SwitchToBuddyPlugin::switchDefinitionDeclaration()
         if (ClassFunctionDeclaration* cDef = dynamic_cast<ClassFunctionDeclaration*>(definition)) {
             if (cDef->isSignal()) {
                 qCDebug(PLUGIN_SWITCHTOBUDDY) << "found definition is a signal, not switching to .moc implementation";
-                definition = 0;
+                definition = nullptr;
                 wasSignal = true;
             }
         }
@@ -259,7 +277,7 @@ void SwitchToBuddyPlugin::switchDefinitionDeclaration()
         qCDebug(PLUGIN_SWITCHTOBUDDY) << "Got no context for the current document";
     }
 
-    Declaration* def = 0;
+    Declaration* def = nullptr;
     if (!wasSignal) {
         def = definitionForCursorDeclaration(cursor, docUrl);
     }
