@@ -82,12 +82,17 @@ void VcsChangesView::popupContextMenu( const QPoint &pos )
             if(idx.parent().isValid())
                 urls += idx.data(KDevelop::VcsFileChangesModel::VcsStatusInfoRole).value<VcsStatusInfo>().url();
             else {
-                projects += ICore::self()->projectController()->findProjectByName(idx.data(ProjectChangesModel::ProjectNameRole).toString());
+                IProject* project = ICore::self()->projectController()->findProjectByName(idx.data(ProjectChangesModel::ProjectNameRole).toString());
+                if (project) {
+                    projects += project;
+                } else {
+                    qWarning() << "Couldn't find a project for project: " << idx.data(ProjectChangesModel::ProjectNameRole).toString();
+                }
             }
         }
     }
 
-    QPointer<QMenu> menu = new QMenu;
+    QPointer<QMenu> menu = new QMenu(this);
     QAction* refreshAction = menu->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Refresh"));
     QList<ContextMenuExtension> extensions;
     if(!urls.isEmpty()) {
@@ -127,7 +132,7 @@ void VcsChangesView::popupContextMenu( const QPoint &pos )
     appendActions(menu, projectActions);
 
     if ( !menu->isEmpty() ) {
-        QAction* res = menu->exec( mapToGlobal( pos ) );
+        QAction* res = menu->exec(viewport()->mapToGlobal(pos));
         if(res == refreshAction) {
             if(!urls.isEmpty())
                 emit reload(urls);
@@ -146,13 +151,10 @@ void VcsChangesView::selectCurrentDocument()
     
     QUrl url = doc->url();
     IProject* p = ICore::self()->projectController()->findProjectForUrl(url);
-    QModelIndex idx;
-    
-    if(p) {
-        ProjectChangesModel* pcmodel = static_cast<ProjectChangesModel*>(model());
-        idx = pcmodel->indexForUrl(url);
-    }
-    
+    QModelIndex idx = (p ?
+        model()->match(model()->index(0, 0), ProjectChangesModel::UrlRole,
+                       url, 1, Qt::MatchExactly).value(0) :
+        QModelIndex());
     if(idx.isValid()) {
         expand(idx.parent());
         setCurrentIndex(idx);
