@@ -99,7 +99,7 @@ KAboutData createAboutData()
     KAboutData aboutData( QStringLiteral("kdevplatform"),
                           i18n("KDevelop Platform"), QStringLiteral(KDEVPLATFORM_VERSION_STRING),
                           i18n("Development Platform for IDE-like Applications"),
-                          KAboutLicense::LGPL_V2, i18n( "Copyright 2004-2016, The KDevelop developers" ),
+                          KAboutLicense::LGPL_V2, i18n( "Copyright 2004-2017, The KDevelop developers" ),
                           QString(), QStringLiteral("http://www.kdevelop.org") );
 
     aboutData.addAuthor( i18n("Andreas Pakulat"), i18n( "Architecture, VCS Support, Project Management Support, QMake Projectmanager" ), QStringLiteral("apaku@gmx.de") );
@@ -429,7 +429,7 @@ void Core::cleanup()
     emit aboutToShutdown();
 
     if (!d->m_cleanedUp) {
-        // first of all: stop background jobs
+        // first of all: request stop of all background parser jobs
         d->languageController->backgroundParser()->abortAllJobs();
         d->languageController->backgroundParser()->suspend();
 
@@ -450,7 +450,11 @@ void Core::cleanup()
         }
         d->projectController.data()->cleanup();
         d->sourceFormatterController.data()->cleanup();
+
+        // before unloading language plugins, we need to make sure all parse jobs are done
+        d->languageController->backgroundParser()->waitForIdle();
         d->pluginController.data()->cleanup();
+
         d->sessionController.data()->cleanup();
 
         d->testController.data()->cleanup();
