@@ -18,12 +18,14 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef KDEVPLATFORM_CORE_P_H
-#define KDEVPLATFORM_CORE_P_H
+#ifndef KDEVPLATFORM_PLATFORM_CORE_P_H
+#define KDEVPLATFORM_PLATFORM_CORE_P_H
 
-#include <kcomponentdata.h>
 #include <core.h>
-#include <QWeakPointer>
+
+#include <KAboutData>
+
+#include <QPointer>
 
 namespace KDevelop
 {
@@ -46,26 +48,26 @@ class TestController;
 
 class KDEVPLATFORMSHELL_EXPORT CorePrivate {
 public:
-    CorePrivate(Core *core);
+    explicit CorePrivate(Core *core);
     ~CorePrivate();
     bool initialize( Core::Setup mode, QString session );
-    QWeakPointer<PluginController> pluginController;
-    QWeakPointer<UiController> uiController;
-    QWeakPointer<ProjectController> projectController;
-    QWeakPointer<LanguageController> languageController;
-    QWeakPointer<PartController> partController;
-    QWeakPointer<DocumentController> documentController;
-    QWeakPointer<RunController> runController;
-    QWeakPointer<SessionController> sessionController;
-    QWeakPointer<SourceFormatterController> sourceFormatterController;
-    QWeakPointer<ProgressManager> progressController;
-    QWeakPointer<SelectionController> selectionController;
-    QWeakPointer<DocumentationController> documentationController;
-    QWeakPointer<DebugController> debugController;
-    QWeakPointer<WorkingSetController> workingSetController;
-    QWeakPointer<TestController> testController;
+    QPointer<PluginController> pluginController;
+    QPointer<UiController> uiController;
+    QPointer<ProjectController> projectController;
+    QPointer<LanguageController> languageController;
+    QPointer<PartController> partController;
+    QPointer<DocumentController> documentController;
+    QPointer<RunController> runController;
+    QPointer<SessionController> sessionController;
+    QPointer<SourceFormatterController> sourceFormatterController;
+    QPointer<ProgressManager> progressController;
+    QPointer<SelectionController> selectionController;
+    QPointer<DocumentationController> documentationController;
+    QPointer<DebugController> debugController;
+    QPointer<WorkingSetController> workingSetController;
+    QPointer<TestController> testController;
 
-    KComponentData m_componentData;
+    KAboutData m_aboutData;
     Core *m_core;
     bool m_cleanedUp;
     bool m_shuttingDown;
