@@ -154,6 +154,8 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent)
         QMenu* suggestionsMenu = type->launcherSuggestions();
 
         if(suggestionsMenu) {
+            // take ownership
+            suggestionsMenu->setParent(m, suggestionsMenu->windowFlags());
             m->addMenu(suggestionsMenu);
         }
     }
@@ -207,14 +209,14 @@ void LaunchConfigurationDialog::doTreeContextMenu(QPoint point)
         QModelIndex selected = tree->selectionModel()->selectedRows().first();
         if ( selected.parent().isValid() && ! selected.parent().parent().isValid() ) {
             // only display the menu if a launch config is clicked
-            QMenu menu;
+            QMenu menu(tree);
             QAction* rename = new QAction(QIcon::fromTheme(QStringLiteral("edit-rename")), i18n("Rename configuration"), &menu);
             QAction* delete_ = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Delete configuration"), &menu);
             connect(rename, &QAction::triggered, this, &LaunchConfigurationDialog::renameSelected);
             connect(delete_, &QAction::triggered, this, &LaunchConfigurationDialog::deleteConfiguration);
             menu.addAction(rename);
             menu.addAction(delete_);
-            menu.exec(tree->mapToGlobal(point));
+            menu.exec(tree->viewport()->mapToGlobal(point));
         }
     }
 }
@@ -636,6 +638,7 @@ QVariant LaunchConfigurationsModel::data(const QModelIndex& index, int role) con
                         return QIcon::fromTheme(QStringLiteral("folder-development"));
                     }
                 }
+                break;
             }
             case Qt::EditRole:
             {
