@@ -374,6 +374,7 @@ void MainWindow::updateCaption()
 {
     const auto activeSession = Core::self()->sessionController()->activeSession();
     QString title = activeSession ? activeSession->description() : QString();
+    QString localFilePath;
 
     if(area()->activeView())
     {
@@ -383,7 +384,12 @@ void MainWindow::updateCaption()
         Sublime::Document* doc = area()->activeView()->document();
         Sublime::UrlDocument* urlDoc = dynamic_cast<Sublime::UrlDocument*>(doc);
         if(urlDoc)
+        {
+            if (urlDoc->url().isLocalFile()) {
+                localFilePath = urlDoc->url().toLocalFile();
+            }
             title += Core::self()->projectController()->prettyFileName(urlDoc->url(), KDevelop::IProjectController::FormatPlain);
+        }
         else
             title += doc->title();
 
@@ -394,6 +400,7 @@ void MainWindow::updateCaption()
         title += QLatin1String(" ]");
     }
 
+    setWindowFilePath(localFilePath);
     setCaption(title);
 }
 
