@@ -51,7 +51,7 @@ class KDEVPLATFORMSHELL_EXPORT MainWindow: public Sublime::MainWindow {
     Q_OBJECT
     Q_CLASSINFO( "D-Bus Interface", "org.kdevelop.MainWindow" )
 public:
-    explicit MainWindow( Sublime::Controller *parent = 0, Qt::WindowFlags flags = KDE_DEFAULT_WINDOWFLAGS );
+    explicit MainWindow(Sublime::Controller *parent = nullptr, Qt::WindowFlags flags = {});
     ~MainWindow() override;
 
     /*! @p status must implement KDevelop::IStatus */
@@ -85,6 +85,7 @@ protected:
     virtual void initialize();
     virtual void cleanup();
     void initializeStatusBar() override;
+    bool event( QEvent* ) override;
     void dragEnterEvent( QDragEnterEvent* ) override;
     void dropEvent( QDropEvent* ) override;
     void applyMainWindowSettings(const KConfigGroup& config) override;
@@ -106,6 +107,8 @@ private Q_SLOTS:
     void shortcutsChanged();
 
 private:
+    void initializeCorners();
+
     class MainWindowPrivate *d;
     friend class MainWindowPrivate;
 };
