@@ -45,7 +45,8 @@ public:
         ValueColumn
     };
 
-    EnvironmentGroupModel();
+    explicit EnvironmentGroupModel(QObject* parent = nullptr);
+
     int rowCount( const QModelIndex &parent = QModelIndex() ) const override;
     int columnCount( const QModelIndex &parent = QModelIndex()  ) const override;
     Qt::ItemFlags flags( const QModelIndex& idx ) const override;
