@@ -125,7 +125,7 @@ void SourceFormatterSettings::reset()
             foreach ( const SourceFormatterStyle::MimeHighlightPair& item, style->mimeTypes() ) {
                 QMimeType mime = QMimeDatabase().mimeTypeForName(item.mimeType);
                 if (!mime.isValid()) {
-                    qWarning() << "plugin" << info.name() << "supports unknown mimetype entry" << item.mimeType;
+                    qCWarning(SHELL) << "plugin" << info.name() << "supports unknown mimetype entry" << item.mimeType;
                     continue;
                 }
                 QString languageName = item.highlightMode;
@@ -279,7 +279,7 @@ void SourceFormatterSettings::enableStyleButtons()
         const LanguageSettings& l = it.value();
         Q_ASSERT(l.selectedFormatter);
         ISourceFormatter* fmt = l.selectedFormatter->formatter;
-        hasEditWidget = ( fmt && fmt->editStyleWidget( l.mimetypes.first() ) );
+        hasEditWidget = ( fmt && QScopedPointer<QObject>(fmt->editStyleWidget( l.mimetypes.first() )) );
     }
     btnDelStyle->setEnabled( userEntry );
     btnEditStyle->setEnabled( userEntry && hasEditWidget );
@@ -402,7 +402,7 @@ void SourceFormatterSettings::editStyle()
     SourceFormatter* fmt = l.selectedFormatter;
 
     QMimeType mimetype = l.mimetypes.first();
-    if( fmt->formatter->editStyleWidget( mimetype ) != nullptr ) {
+    if( QScopedPointer<QObject>(fmt->formatter->editStyleWidget( mimetype )) ) {
         EditStyleDialog dlg( fmt->formatter, mimetype, *l.selectedStyle, this );
         if( dlg.exec() == QDialog::Accepted )
         {
