@@ -138,29 +138,30 @@ class FakePluginController : public PluginController
 {
     Q_OBJECT
 public:
-    FakePluginController(Core* core)
-        : PluginController(core)
-        , m_fakeFileManager(new FakeFileManager)
-    {
-    }
+    using PluginController::PluginController;
 
     IPlugin* pluginForExtension(const QString& extension, const QString& pluginName = {}, const QVariantMap& constraints = QVariantMap()) override
     {
         if (extension == qobject_interface_iid<IProjectFileManager*>()) {
+            if (!m_fakeFileManager) {
+                // Can't initialize in the constructor, because the pluginController must be setup
+                //  before constructing a plugin, and this _is_ the pluginController.
+                m_fakeFileManager = new FakeFileManager;
+            }
             return m_fakeFileManager;
         }
         return PluginController::pluginForExtension(extension, pluginName, constraints);
     }
 
 private:
-    FakeFileManager* m_fakeFileManager;
+    FakeFileManager* m_fakeFileManager = nullptr;
 };
 
 ////////////////////// Fixture ///////////////////////////////////////////////
 
 void TestProjectController::initTestCase()
 {
-    AutoTestShell::init();
+    AutoTestShell::init({{}});
     TestCore* testCore = new TestCore;
     testCore->setPluginController( new FakePluginController(testCore) );
     testCore->initialize();
