@@ -61,7 +61,7 @@ void WorkingSetToolButton::setWorkingSet(WorkingSet* set)
 
 void WorkingSetToolButton::contextMenuEvent(QContextMenuEvent* ev)
 {
-    showTooltip();
+    showTooltip(ev->globalPos());
 
     ev->accept();
 }
@@ -131,7 +131,8 @@ void WorkingSetToolButton::closeSet(bool ask)
 bool WorkingSetToolButton::event(QEvent* e)
 {
     if(m_toolTipEnabled && e->type() == QEvent::ToolTip) {
-        showTooltip();
+        QHelpEvent* helpEvent = static_cast<QHelpEvent*>(e);
+        showTooltip(helpEvent->globalPos());
         e->accept();
         return true;
     }
@@ -139,7 +140,7 @@ bool WorkingSetToolButton::event(QEvent* e)
     return QToolButton::event(e);
 }
 
-void WorkingSetToolButton::showTooltip()
+void WorkingSetToolButton::showTooltip(const QPoint& globalPos)
 {
     Q_ASSERT(m_set);
     static WorkingSetToolButton* oldTooltipButton;
@@ -151,7 +152,7 @@ void WorkingSetToolButton::showTooltip()
 
     oldTooltipButton = this;
 
-    controller->showToolTip(m_set, QCursor::pos() + QPoint(10, 20));
+    controller->showToolTip(m_set, globalPos + QPoint(10, 20));
 
     QRect extended(parentWidget()->mapToGlobal(geometry().topLeft()),
                     parentWidget()->mapToGlobal(geometry().bottomRight()));
@@ -163,7 +164,7 @@ void WorkingSetToolButton::buttonTriggered()
     Q_ASSERT(m_set);
 
     if(mainWindow()->area()->workingSet() == m_set->id()) {
-        showTooltip();
+        showTooltip(QCursor::pos());
     }else{
         //Only close the working-set if the file was saved before
         if(!Core::self()->documentControllerInternal()->saveAllDocumentsForWindow(mainWindow(), KDevelop::IDocument::Default, true))
