@@ -32,6 +32,7 @@
 #include <QStylePainter>
 #include <QTabBar>
 #include <QToolButton>
+#include <QWindow>
 
 #include <KAcceleratorManager>
 #include <KConfig>
@@ -76,7 +77,8 @@ public:
         {
             ev->accept();
 
-            int tab = tabAt(mapFromGlobal(QCursor::pos()));
+            QHelpEvent* helpEvent = static_cast<QHelpEvent*>(ev);
+            int tab = tabAt(helpEvent->pos());
 
             if(tab != -1)
             {
@@ -92,7 +94,7 @@ public:
         if (event->button() == Qt::MidButton) {
             // just close on midbutton, drag can still be done with left mouse button
 
-            int tab = tabAt(mapFromGlobal(QCursor::pos()));
+            int tab = tabAt(event->pos());
             if (tab != -1) {
                 emit tabCloseRequested(tab);
             }
@@ -132,6 +134,11 @@ bool sortViews(const View* const lhs, const View* const rhs)
         return lhs->document()->title().compare(rhs->document()->title(), Qt::CaseInsensitive) < 0;
 }
 
+#ifdef Q_OS_MACOS
+// only one of these per process:
+static QMenu* currentDockMenu = nullptr;
+#endif
+
 struct ContainerPrivate {
     QBoxLayout* layout;
     QHash<QWidget*, View*> viewForWidget;
@@ -196,6 +203,28 @@ struct ContainerPrivate {
             ///FIXME: push this code somehow into shell, such that we can access the project model for
             ///       icons and also get a neat, short path like the document switcher.
         }
+
+        setAsDockMenu();
+    }
+
+    void setAsDockMenu()
+    {
+#ifdef Q_OS_MACOS
+        if (documentListMenu != currentDockMenu) {
+            documentListMenu->setAsDockMenu();
+            currentDockMenu = documentListMenu;
+        }
+#endif
+    }
+
+    ~ContainerPrivate()
+    {
+#ifdef Q_OS_MACOS
+        if (documentListMenu == currentDockMenu) {
+            QMenu().setAsDockMenu();
+            currentDockMenu = nullptr;
+        }
+#endif
     }
 };
 
@@ -283,6 +312,10 @@ Container::Container(QWidget *parent)
     d->documentListButton = new QToolButton(this);
     d->documentListButton->setIcon(QIcon::fromTheme(QStringLiteral("format-list-unordered")));
     d->documentListButton->setMenu(d->documentListMenu);
+#ifdef Q_OS_MACOS
+    // for maintaining the Dock menu:
+    setFocusPolicy(Qt::StrongFocus);
+#endif
     d->documentListButton->setPopupMode(QToolButton::InstantPopup);
     d->documentListButton->setAutoRaise(true);
     d->documentListButton->setToolTip(i18n("Show sorted list of opened documents"));
@@ -457,14 +490,12 @@ QWidget* Container::currentWidget() const
 
 void Container::setCurrentWidget(QWidget* w)
 {
-    d->stack->setCurrentWidget(w);
-    //prevent from emitting activateView() signal on tabbar active tab change
-    //this function is called from MainWindow::activateView()
-    //which does the activation without any additional signals
-    {
-        QSignalBlocker blocker(d->tabBar);
-        d->tabBar->setCurrentIndex(d->stack->indexOf(w));
+
+    if (d->stack->currentWidget() == w) {
+        return;
     }
+    d->stack->setCurrentWidget(w);
+    d->tabBar->setCurrentIndex(d->stack->indexOf(w));
     if (View* view = viewForWidget(w))
     {
         statusChanged(view);
@@ -590,6 +621,17 @@ void Container::contextMenu( const QPoint& pos )
     int currentTab = d->tabBar->tabAt(pos);
 
     QMenu menu;
+    // At least for positioning on Wayland the window the menu belongs to
+    // needs to be set. We cannot set senderWidget as parent because some actions (e.g. split view)
+    // result in sync destruction of the senderWidget, which then would also prematurely
+    // destruct the menu object
+    // Workaround (best known currently, check again API of Qt >5.9):
+    menu.winId(); // trigger being a native widget already, to ensure windowHandle created
+    auto parentWindowHandle = senderWidget->windowHandle();
+    if (!parentWindowHandle) {
+        parentWindowHandle = senderWidget->nativeParentWidget()->windowHandle();
+    }
+    menu.windowHandle()->setTransientParent(parentWindowHandle);
 
     Sublime::View* view = viewForWidget(widget(currentTab));
     emit tabContextMenuRequested(view, &menu);
@@ -607,7 +649,7 @@ void Container::contextMenu( const QPoint& pos )
         closeOtherTabsAction = menu.addAction(QIcon::fromTheme(QStringLiteral("document-close")),
                                               i18n("Close Other Files"));
     }
-    QAction* closeAllTabsAction = menu.addAction( QIcon::fromTheme(QStringLiteral("document-close")), i18n( "Close All Files" ) );
+    QAction* closeAllTabsAction = menu.addAction(QIcon::fromTheme(QStringLiteral("document-close")), i18n("Close All Files"));
 
     QAction* triggered = menu.exec(senderWidget->mapToGlobal(pos));
 
@@ -683,6 +725,12 @@ Sublime::View* Container::currentView() const
     return d->viewForWidget.value(widget( d->tabBar->currentIndex() ));
 }
 
+void Container::focusInEvent(QFocusEvent* event)
+{
+    d->setAsDockMenu();
+    QWidget::focusInEvent(event);
+}
+
 }
 
 #include "container.moc"
