@@ -20,8 +20,8 @@
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
 
-#ifndef SUBLIME_IDEAL_H
-#define SUBLIME_IDEAL_H
+#ifndef SUBLIME_IDEALCONTROLLER_H
+#define SUBLIME_IDEALCONTROLLER_H
 
 #include <QAction>
 #include <QActionEvent>
