@@ -95,7 +95,7 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
     QWidget* senderWidget = qobject_cast<QWidget*>(sender());
     Q_ASSERT(senderWidget);
 
-    QMenu menu;
+    QMenu menu(senderWidget);
     menu.addSection(windowIcon(), m_view->document()->title());
 
     QList< QAction* > viewActions = m_view->contextMenuActions();
@@ -113,7 +113,7 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
     /// start position menu
     QMenu* positionMenu = menu.addMenu(i18n("Toolview Position"));
 
-    QActionGroup *g = new QActionGroup(this);
+    QActionGroup* g = new QActionGroup(positionMenu);
 
     QAction *left = new QAction(i18nc("toolview position", "Left"), g);
     QAction *bottom = new QAction(i18nc("toolview position", "Bottom"), g);
