@@ -53,18 +53,18 @@ class KDEVPLATFORMVCS_EXPORT DistributedVersionControlPlugin : public IPlugin, p
 public:
 
     DistributedVersionControlPlugin(QObject *parent, const QString& componentName);
-    virtual ~DistributedVersionControlPlugin();
+    ~DistributedVersionControlPlugin() override;
 
     // Begin: KDevelop::IBasicVersionControl
 
     /** Used in KDevelop's appwizardplugin (creates import widget) */
-    virtual VcsImportMetadataWidget* createImportMetadataWidget(QWidget* parent) override;
+    VcsImportMetadataWidget* createImportMetadataWidget(QWidget* parent) override;
 
     // From KDevelop::IPlugin
     /** Creates context menu
      * @note Create only special items here (like checkout), all standard menu items are created in vcscommon plugin!
      */
-    virtual ContextMenuExtension contextMenuExtension(Context*) override;
+    ContextMenuExtension contextMenuExtension(Context*) override;
 
     /**
       * Parses the output generated by a @code dvcs log @endcode command and
