@@ -386,6 +386,7 @@ void VcsPluginHelper::annotation()
         }
 
         if (annotateiface && viewiface) {
+            // TODO: only create model if there is none yet (e.g. from another view)
             KDevelop::VcsAnnotationModel* model = new KDevelop::VcsAnnotationModel(job, url, doc->textDocument(),
                                                                                    foreground, background);
             annotateiface->setAnnotationModel(model);
@@ -394,6 +395,8 @@ void VcsPluginHelper::annotation()
             connect(doc->activeTextView(),
                     SIGNAL(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)),
                     this, SLOT(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)));
+            connect(doc->activeTextView(), SIGNAL(annotationBorderVisibilityChanged(View*,bool)),
+                    this, SLOT(handleAnnotationBorderVisibilityChanged(View*,bool)));
         } else {
             KMessageBox::error(nullptr, i18n("Cannot display annotations, missing interface KTextEditor::AnnotationInterface for the editor."));
             delete job;
@@ -426,7 +429,7 @@ void VcsPluginHelper::annotationContextMenuAboutToShow( KTextEditor::View* view,
     menu->addAction(d->diffForRevGlobalAction);
     QAction* action = nullptr;
     action = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Revision"));
-    connect(action, &QAction::triggered, this, [this, rev]() {
+    connect(action, &QAction::triggered, this, [rev]() {
         QApplication::clipboard()->setText(rev.revisionValue().toString());
     });
     action = menu->addAction(QIcon::fromTheme(QStringLiteral("view-history")), i18n("History..."));
@@ -435,6 +438,21 @@ void VcsPluginHelper::annotationContextMenuAboutToShow( KTextEditor::View* view,
     });
 }
 
+void VcsPluginHelper::handleAnnotationBorderVisibilityChanged(View* view, bool visible)
+{
+    if (visible) {
+        return;
+    }
+
+    disconnect(view, SIGNAL(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)),
+               this, SLOT(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)));
+
+    disconnect(view, SIGNAL(annotationBorderVisibilityChanged(View*,bool)),
+               this, SLOT(handleAnnotationBorderVisibilityChanged(View*,bool)));
+
+    // TODO: remove the model if last user of it
+}
+
 void VcsPluginHelper::update()
 {
     EXECUTE_VCS_METHOD(update);
